Skip to Content.
Sympa Menu

ndt-dev - [ndt-dev] [ndt] r892 committed - Embedded flash client into html page

Subject: NDT-DEV email list created

List archive

[ndt-dev] [ndt] r892 committed - Embedded flash client into html page


Chronological Thread 
  • From:
  • To:
  • Subject: [ndt-dev] [ndt] r892 committed - Embedded flash client into html page
  • Date: Mon, 10 Feb 2014 13:25:01 +0000

Revision: 892
Author:

Date: Mon Feb 10 13:24:43 2014 UTC
Log: Embedded flash client into html page

http://code.google.com/p/ndt/source/detail?r=892

Added:
/branches/FlashIssue110/tcpbw100-java.template
/branches/FlashIssue110/test-description.html
/branches/FlashIssue110/test-header.html
Modified:
/branches/FlashIssue110/Makefile.am
/branches/FlashIssue110/conf/create-html.sh
Replaced:
/branches/FlashIssue110/tcpbw100.template

=======================================
--- /dev/null
+++ /branches/FlashIssue110/tcpbw100-java.template Mon Feb 10 13:24:43 2014 UTC
@@ -0,0 +1,98 @@
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+<html>
+<head>
+<title>YOURSITE NDT server</title>
+<meta http-equiv="Content-Language" content="en">
+<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+</head>
+<body onload="setTimeout('setUserAgent()', 2000)">
+<h3> YOURSITE Web100 based Network Diagnostic Tool (NDT) </h3>
+<b>Located at YOURLOCATION;
+YOURSPEED network connection</b>
+<br><font size=-1>
+<iframe width="100%" height="350" frameborder="0" src="test-header.html"></iframe>
+ This is java version of client. If you want to use flash app instead, please visit <a href="tcpbw100.html">this site</a>
+<!-- this applet will email results to the person specified by the
+ param parameters. The 'H' value is the hostname, the 'U' value
+ is the username. The 'subject' line overwrites the default message
+ built into the java program. -->
+
+<table align=center><tr><td>
+<applet code="edu.internet2.ndt.Tcpbw100.class" name="NDTApplet" ARCHIVE="Tcpbw100.jar"
+ width=700 height=320>
+ <PARAM NAME="H" VALUE="YOURDOMAIN">
+ <PARAM NAME="U" VALUE="YOUREMAIL">
+ <PARAM NAME="subject" VALUE="YOURSUBJECT">
+
+<!--
+ JZ 2/14/2013: Localization Support
+
+ Greek/Greece
+ <PARAM NAME="language" VALUE="el">
+ <PARAM NAME="country" VALUE="GR">
+
+ Norwegian/Norway
+ <PARAM NAME="language" VALUE="nb">
+ <PARAM NAME="country" VALUE="NO">
+
+ Dutch/Netherlands
+ <PARAM NAME="language" VALUE="nl">
+ <PARAM NAME="country" VALUE="NL">
+
+ Catalan/Spain
+ <PARAM NAME="language" VALUE="ca">
+ <PARAM NAME="country" VALUE="ES">
+
+ Russian/Russia
+ <PARAM NAME="language" VALUE="ru">
+ <PARAM NAME="country" VALUE="RU">
+
+ French/France
+ <PARAM NAME="language" VALUE="fr">
+ <PARAM NAME="country" VALUE="FR">
+
+ Portugese/Brazil
+ <PARAM NAME="language" VALUE="pt">
+ <PARAM NAME="country" VALUE="BR">
+
+ English/US
+ <PARAM NAME="language" VALUE="en">
+ <PARAM NAME="country" VALUE="US">
+-->
+
+ <PARAM NAME="language" VALUE="en">
+ <PARAM NAME="country" VALUE="US">
+ <PARAM NAME="client" VALUE="applet">
+
+</applet>
+</td></tr></table>
+
+<br>
+<a
href="mailto:YOUREMAIL@YOURDOMAIN?subject=YOURSUBJECT
+?&amp;body=Your name: %0aEmail: %0aHostname: %0a%0aPaste results from%20
+'Statistics' window here:%0a%0a%0aPaste results from 'More Details' window%20
+here:%0a%0a%0aComments:%0a">Report Problems</a> <font size=-1> &nbsp; &nbsp; &nbsp; &nbsp; Use "ctrl-C"
+to copy data onto the clipboard and then paste it into the email message. </font>
+
+<hr size=3 width="99%" noshade>
+<br>
+<iframe width="100%" height="920" frameborder="0" src="test-description.html"></iframe>
+This java applet was originally developed by ORNL and has been extensively modified
+at ANL.
+<br>
+Complete University of Chicago <a href="copyright.html">Copyright Notice</a>
+<hr noshade width="90%" size=-4>
+Comments to <a href="mailto:"> Rich Carlson </a> email:
+<br><i>Created: April 4, 2002 by Rich Carlson
+<br>Last Updated: March 16, 2010 by Jason Zurawski</i>
+
+<script language="javascript" type="text/javascript">
+
+ function setUserAgent() {
+ document.NDTApplet.setUserAgent(navigator.userAgent);
+ }
+
+</script>
+
+</body>
+</html>
=======================================
--- /dev/null
+++ /branches/FlashIssue110/test-description.html Mon Feb 10 13:24:43 2014 UTC
@@ -0,0 +1,112 @@
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+<html>
+<head>
+<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+</head>
+<body>
+<p>The NDT performs 2 TCP throughput tests between your desktop
+computer and this NDT server. First, data is streamed for 10 seconds from your
+desktop to the server and then a second 10 second test is performed in the
+opposite direction. A <a href="http://www.web100.org";>Web100</a> modified linux kernel
+captures detailed statistics on these TCP data flows. This data is then analyzed to
+determine why the connection achieved the throughput results it reported.
+<p>
+<h3> Understanding the test results </h3>
+<p>
+End-to-End performance depends upon a number factors. One of the biggest factors
+is setting the tunable network parametes to the proper value. There are several
+web sites that provide detailed tuning instructions for various Operating Systems.
+Two of the best are:
+<ul>
+<li><a href=http://www.psc.edu/networking/projects/tcptune>PSC's Enabling High
+Performance Data Transfers</a></li>
+<li><a href=http://fasterdata.es.net/TCP-tuning>ESnet's TCP Tuning Guide</a></li>
+</ul>
+The throughput an application achieves is dependant on the amount of buffer space
+available in the sending and receiving hosts, packet loss due to errors or congestion,
+packet size (usually limited to 1500 bytes by Ethernet), and the round trip time
+between the 2 hosts. If this test reports that the sender or receiver buffer size
+is the limiting factor, increase the buffer size by
+<a href="http://www.psc.edu/networking/perf_tune.html";>changing the default buffer size</a>
+on your computer. Win 95/98/NT users can easily set and change their default buffer size
+by using the <a href="http://moat.nlanr.net/Software/TCPtune/";>TCPtune application</a>
+developed by the NLANR MOAT group. Windows users may find that they perfer the
+<a href="http://www.dslreports.com/front/drtcp.html";>DrTCP</a> tool from the dslreports.com
+web site.
+<p>
+If a large number of retransmissions occur,
+check the duplex and speed setting on your host and the network switch it attaches
+to (duplex mismatches are a serious problem due to broken autonegoation protocols).
+Extremely long round trip times (over 1 sec) ususally indicate that a network router
+or switch is congested leading to long queuing times. Contact your local network
+administrator for help in solving this problem
+<p>
+The Bandwidth * Delay product is reported in the details section.
+Throughput limits for the NDT server's transmit buffer, your clients receive buffer,
+and the network infrastructure. You may use these numbers as a guide to determining
+what your client's receive buffer is currently set to. Divide the buffer size by
+the reported round trip time (RTT) to calculate the throughput value.
+<p>
+For more info on TCP tuning, visit dslreports.com <a href="http://www.dslreports.com/tweaks/";>tweaks</a>
+or <a href="http://www.psc.edu/networking/perf_tune.html";>UNIX and
+Windows TCP/IP tuning tips</a>.
+<p>
+You can find the Web100 variables descriptions gathered on the following <a href="web100variables.html">web page</a>.
+<hr width="95%" noshade>
+
+<!--
+<h3>REN accessable NDT servers:</h3>
+<p>A list of servers known to the Researh and Education Network (REN) community is
+ located on the <a href="http://e2epi.internet2.edu/ndt/ndt-server-list.html";>Internet2
+ e2epi web page</a>. Note: that not all of these REN servers will be publicly
+ accesible.
+<h3>Other publicly accessible NDT servers:</h3>
+<ul>
+<li><a href="http://ndt.anl.gov:7123";>Argonne National Laboratory - IL (USA)</a></li>
+<li><a href="http://ndt.switch.ch";>Swiss Education and Research Network (Switzerland)</a></li>
+<li><a href="http://web100.rit.edu:7123";>Rochester Institute of Technology - Rochester NY (USA)</a></li>
+<li><a href="http://speedtest.umflint.edu";>University of Michigan - Flint MI (USA)</a></li>
+<li><a href="http://nitro.ucsc.edu/";>University of California - Santa Cruz CA (USA)</a></li>
+<li><a href="http://netspeed.stanford.edu/";>Stanford University - Palo Alto CA (USA)</a></li>
+<li><a href="http://jlab4.jlab.org:7123";>Thomas Jefferson National Accelerator Facility - VA (USA)</a></li>
+<li><a href="http://ciseweb100.cise-nsf.gov:7123";>National Science Foundation - VA (USA)</a></li>
+</ul>
+<br><br>
+-->
+
+
+<h3>Other bandwidth testing sites:</h3>
+<ul>
+<li> <a href="http://www.dslreports.com/tools";> upload/download tester</a></li>
+<li> <a href="http://www.dslreports.com/stest/0";>www.dslreports.com speed test</a> browser/throughput tester</li>
+<li> the older ORNL java <a href="http://www.epm.ornl.gov/~dunigan/java/misc/tcpbw.html";> bandwidth tester</a></li>
+</ul>
+<p>
+You can see the hops (routers) that your packets pass through from
+your machine to a target Internet site with the <i>traceroute</i> command
+(for Windows, use <i>tracert</i> in DOS/command prompt window).
+The route can actually vary from packet to packet, test to test,
+and the reverse route (return path) may not be the same.
+There are several
+<a href="http://www.slac.stanford.edu/comp/net/wan-mon/traceroute-srv.html";>
+traceroute servers</a> around the world that can show you the
+route back to your browser.
+Tom Dunigan at ORNL also has traceroute servers at
+<a href="http://www.epm.ornl.gov/~dunigan/cgi-bin/traceroute.cgi";>ORNL</a>.
+
+<p>
+The NDT server window size for this tester is 64KB.
+Max window used to be 64KB, but newer OS's now support window scaling,
+so you may be able to request more than 64 KB.
+(This NDT server a window of 64,000 bytes,
+and the network interface is 100 Mbs.)
+<p>
+
+The NDT software (source and compiled programs) is available via the Internet2 Performance web site at <a href="http://www.internet2.edu/performance/ndt/download.html";>www.internet2.edu/performance/ndt/download.html</a>. You can also learn more about the NDT system by subscribing to the
+<a href="https://mail.internet2.edu/wws/info/ndt-users";>NDT user discussion</a>
+or <a href="https://mail.internet2.edu/wws/info/ndt-announce";>NDT announcement</a>
+lists hosted by Internet2.
+<p>
+
+</body>
+</html>
=======================================
--- /dev/null
+++ /branches/FlashIssue110/test-header.html Mon Feb 10 13:24:43 2014 UTC
@@ -0,0 +1,24 @@
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+<html>
+<head>
+<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+</head>
+<body>
+This component was developed to test the reliablity and operational
+status of your desktop computer and network connection. It does this by sending data between your
+computer and this remote NDT server. These tests will determine:</font>
+<ul>
+ <li><font size=-1>The slowest link in the end-to-end path (Dial-up modem to 10 Gbps Ethernet/OC-192)</font>
+ <li><font size=-1>The Ethernet duplex setting (full or half);</font>
+ <li><font size=-1>If congestion is limiting end-to-end throughput.</font>
+</ul>
+<br><font size=-1>
+It can also identify 2 serious error conditions:</font>
+<ul>
+ <li><font size=-1>Duplex Mismatch</font>
+ <li><font size=-1>Excessive packet loss due to faulty cables.</font>
+</ul>
+<br>A test takes about 20 seconds. Click on "start" to begin.
+
+</body>
+</html>
=======================================
--- /branches/FlashIssue110/Makefile.am Wed Feb 5 13:31:05 2014 UTC
+++ /branches/FlashIssue110/Makefile.am Mon Feb 10 13:24:43 2014 UTC
@@ -30,7 +30,7 @@
endif

EXTRA_DIST = admin_description.html admin.html \
- tcpbw100.template copyright.html web100variables.html \
+ tcpbw100.template tcpbw100-java.template test-header.html test-description.html copyright.html web100variables.html \
web100_variables COPYRIGHT \
DISCUSSION-LIST FILES Readme-fakewww Readme-web100srv \
contrib/README contrib/loadmap.intro contrib/loadmap.js \
=======================================
--- /branches/FlashIssue110/tcpbw100.template Sat Feb 8 03:11:00 2014 UTC
+++ /branches/FlashIssue110/tcpbw100.template Mon Feb 10 13:24:43 2014 UTC
@@ -5,198 +5,28 @@
<meta http-equiv="Content-Language" content="en">
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
-<body onload="setTimeout('setUserAgent()', 2000)">
+<body>
<h3> YOURSITE Web100 based Network Diagnostic Tool (NDT) </h3>
<b>Located at YOURLOCATION;
YOURSPEED network connection</b>
<br><font size=-1>
-This java applet was developed to test the reliablity and operational
-status of your desktop computer and network connection. It does this by sending data between your
-computer and this remote NDT server. These tests will determine:</font>
-<ul>
- <li><font size=-1>The slowest link in the end-to-end path (Dial-up modem to 10 Gbps Ethernet/OC-192)</font>
- <li><font size=-1>The Ethernet duplex setting (full or half);</font>
- <li><font size=-1>If congestion is limiting end-to-end throughput.</font>
-</ul>
-<br><font size=-1>
-It can also identify 2 serious error conditions:</font>
-<ul>
- <li><font size=-1>Duplex Mismatch</font>
- <li><font size=-1>Excessive packet loss due to faulty cables.</font>
-</ul>
-<br>A test takes about 20 seconds. Click on "start" to begin.
-
-<!-- this applet will email results to the person specified by the
- param parameters. The 'H' value is the hostname, the 'U' value
- is the username. The 'subject' line overwrites the default message
- built into the java program. -->
-
+<iframe width="100%" height="350" frameborder="0" src="test-header.html"></iframe>
+<br>
+ This is flash version of client. If you want to use java applet instead, please visit <a href="tcpbw100-java.html">this site</a>
<table align=center><tr><td>
-<applet code="edu.internet2.ndt.Tcpbw100.class" name="NDTApplet" ARCHIVE="Tcpbw100.jar"
- width=700 height=320>
- <PARAM NAME="H" VALUE="YOURDOMAIN">
- <PARAM NAME="U" VALUE="YOUREMAIL">
- <PARAM NAME="subject" VALUE="YOURSUBJECT">
-
-<!--
- JZ 2/14/2013: Localization Support
-
- Greek/Greece
- <PARAM NAME="language" VALUE="el">
- <PARAM NAME="country" VALUE="GR">
-
- Norwegian/Norway
- <PARAM NAME="language" VALUE="nb">
- <PARAM NAME="country" VALUE="NO">
-
- Dutch/Netherlands
- <PARAM NAME="language" VALUE="nl">
- <PARAM NAME="country" VALUE="NL">
-
- Catalan/Spain
- <PARAM NAME="language" VALUE="ca">
- <PARAM NAME="country" VALUE="ES">
-
- Russian/Russia
- <PARAM NAME="language" VALUE="ru">
- <PARAM NAME="country" VALUE="RU">
-
- French/France
- <PARAM NAME="language" VALUE="fr">
- <PARAM NAME="country" VALUE="FR">
-
- Portugese/Brazil
- <PARAM NAME="language" VALUE="pt">
- <PARAM NAME="country" VALUE="BR">
-
- English/US
- <PARAM NAME="language" VALUE="en">
- <PARAM NAME="country" VALUE="US">
--->
-
- <PARAM NAME="language" VALUE="en">
- <PARAM NAME="country" VALUE="US">
- <PARAM NAME="client" VALUE="applet">
-
-</applet>
+<embed type="application/x-shockwave-flash" src="FlashClt.swf" width="600" height="400" id="flash_client" name="flash_client" />
</td></tr></table>

<br>
<a
href="mailto:YOUREMAIL@YOURDOMAIN?subject=YOURSUBJECT
?&amp;body=Your name: %0aEmail: %0aHostname: %0a%0aPaste results from%20
-'Statistics' window here:%0a%0a%0aPaste results from 'More Details' window%20
+'Results' page here:%0a%0a%0aPaste results from 'Details' page%20
here:%0a%0a%0aComments:%0a">Report Problems</a> <font size=-1> &nbsp; &nbsp; &nbsp; &nbsp; Use "ctrl-C"
to copy data onto the clipboard and then paste it into the email message. </font>

<hr size=3 width="99%" noshade>
<br>
-<p>The NDT performs 2 TCP throughput tests between your desktop
-computer and this NDT server. First, data is streamed for 10 seconds from your
-desktop to the server and then a second 10 second test is performed in the
-opposite direction. A <a href="http://www.web100.org";>Web100</a> modified linux kernel
-captures detailed statistics on these TCP data flows. This data is then analyzed to
-determine why the connection achieved the throughput results it reported.
-<p>
-<h3> Understanding the test results </h3>
-<p>
-End-to-End performance depends upon a number factors. One of the biggest factors
-is setting the tunable network parametes to the proper value. There are several
-web sites that provide detailed tuning instructions for various Operating Systems.
-Two of the best are:
-<ul>
-<li><a href=http://www.psc.edu/networking/projects/tcptune>PSC's Enabling High
-Performance Data Transfers</a></li>
-<li><a href=http://fasterdata.es.net/TCP-tuning>ESnet's TCP Tuning Guide</a></li>
-</ul>
-The throughput an application achieves is dependant on the amount of buffer space
-available in the sending and receiving hosts, packet loss due to errors or congestion,
-packet size (usually limited to 1500 bytes by Ethernet), and the round trip time
-between the 2 hosts. If this test reports that the sender or receiver buffer size
-is the limiting factor, increase the buffer size by
-<a href="http://www.psc.edu/networking/perf_tune.html";>changing the default buffer size</a>
-on your computer. Win 95/98/NT users can easily set and change their default buffer size
-by using the <a href="http://moat.nlanr.net/Software/TCPtune/";>TCPtune application</a>
-developed by the NLANR MOAT group. Windows users may find that they perfer the
-<a href="http://www.dslreports.com/front/drtcp.html";>DrTCP</a> tool from the dslreports.com
-web site.
-<p>
-If a large number of retransmissions occur,
-check the duplex and speed setting on your host and the network switch it attaches
-to (duplex mismatches are a serious problem due to broken autonegoation protocols).
-Extremely long round trip times (over 1 sec) ususally indicate that a network router
-or switch is congested leading to long queuing times. Contact your local network
-administrator for help in solving this problem
-<p>
-The Bandwidth * Delay product is reported at the bottom of the "more details" page.
-Throughput limits for the NDT server's transmit buffer, your clients receive buffer,
-and the network infrastructure. You may use these numbers as a guide to determining
-what your client's receive buffer is currently set to. Divide the buffer size by
-the reported round trip time (RTT) to calculate the throughput value.
-<p>
-For more info on TCP tuning, visit dslreports.com <a href="http://www.dslreports.com/tweaks/";>tweaks</a>
-or <a href="http://www.psc.edu/networking/perf_tune.html";>UNIX and
-Windows TCP/IP tuning tips</a>.
-<p>
-You can find the Web100 variables descriptions gathered on the following <a href="web100variables.html">web page</a>.
-<hr width="95%" noshade>
-
-<!--
-<h3>REN accessable NDT servers:</h3>
-<p>A list of servers known to the Researh and Education Network (REN) community is
- located on the <a href="http://e2epi.internet2.edu/ndt/ndt-server-list.html";>Internet2
- e2epi web page</a>. Note: that not all of these REN servers will be publicly
- accesible.
-<h3>Other publicly accessible NDT servers:</h3>
-<ul>
-<li><a href="http://ndt.anl.gov:7123";>Argonne National Laboratory - IL (USA)</a></li>
-<li><a href="http://ndt.switch.ch";>Swiss Education and Research Network (Switzerland)</a></li>
-<li><a href="http://web100.rit.edu:7123";>Rochester Institute of Technology - Rochester NY (USA)</a></li>
-<li><a href="http://speedtest.umflint.edu";>University of Michigan - Flint MI (USA)</a></li>
-<li><a href="http://nitro.ucsc.edu/";>University of California - Santa Cruz CA (USA)</a></li>
-<li><a href="http://netspeed.stanford.edu/";>Stanford University - Palo Alto CA (USA)</a></li>
-<li><a href="http://jlab4.jlab.org:7123";>Thomas Jefferson National Accelerator Facility - VA (USA)</a></li>
-<li><a href="http://ciseweb100.cise-nsf.gov:7123";>National Science Foundation - VA (USA)</a></li>
-</ul>
-<br><br>
--->
-
-
-<h3>Other bandwidth testing sites:</h3>
-<ul>
-<li> <a href="http://www.dslreports.com/tools";> upload/download tester</a></li>
-<li> <a href="http://www.dslreports.com/stest/0";>www.dslreports.com speed test</a> browser/throughput tester</li>
-<li> the older ORNL java <a href="http://www.epm.ornl.gov/~dunigan/java/misc/tcpbw.html";> bandwidth tester</a></li>
-</ul>
-<p>
-You can see the hops (routers) that your packets pass through from
-your machine to a target Internet site with the <i>traceroute</i> command
-(for Windows, use <i>tracert</i> in DOS/command prompt window).
-The route can actually vary from packet to packet, test to test,
-and the reverse route (return path) may not be the same.
-There are several
-<a href="http://www.slac.stanford.edu/comp/net/wan-mon/traceroute-srv.html";>
-traceroute servers</a> around the world that can show you the
-route back to your browser.
-Tom Dunigan at ORNL also has traceroute servers at
-<a href="http://www.epm.ornl.gov/~dunigan/cgi-bin/traceroute.cgi";>ORNL</a>.
-
-<p>
-The NDT server window size for this Java tester is 64KB.
-Max window used to be 64KB, but newer OS's now support window scaling,
-so you may be able to request more than 64 KB.
-(This NDT server a window of 64,000 bytes,
-and the network interface is 100 Mbs.)
-<p>
-
-The NDT software (source and compiled programs) is available via the Internet2 Performance web site at <a href="http://www.internet2.edu/performance/ndt/download.html";>www.internet2.edu/performance/ndt/download.html</a>. You can also learn more about the NDT system by subscribing to the
-<a href="https://mail.internet2.edu/wws/info/ndt-users";>NDT user discussion</a>
-or <a href="https://mail.internet2.edu/wws/info/ndt-announce";>NDT announcement</a>
-lists hosted by Internet2.
-<p>
-This java applet was originally developed by ORNL and has been extensively modified
-at ANL.
-<br>
-Complete University of Chicago <a href="copyright.html">Copyright Notice</a>
+<iframe width="100%" height="920" frameborder="0" src="test-description.html"></iframe>
<hr noshade width="90%" size=-4>
Comments to <a href="mailto:"> Rich Carlson </a> email:
<br><i>Created: April 4, 2002 by Rich Carlson


  • [ndt-dev] [ndt] r892 committed - Embedded flash client into html page, ndt, 02/10/2014

Archive powered by MHonArc 2.6.16.

Top of Page
--- /branches/FlashIssue110/conf/create-html.sh Fri Mar 28 16:19:35 2008 UTC
+++ /branches/FlashIssue110/conf/create-html.sh Mon Feb 10 13:24:43 2014 UTC
@@ -1,14 +1,14 @@
#!/bin/bash

# This script creates the basic tcpbw100.html page needed by
# the NDT server.
#
# First prompt the user for some local data variables, site name
# and location, email address and subject line for reports, and
# the local link connection info.
#
# Then create the html file using the tcpbw100.template file
# modified by sed.
#
# Richard Carlson
#

@@ -16,7 +16,7 @@
#

echo "Welcome to the NDT server configuration program. This"
-echo "program will create a custom tcpbw100.html file for your site."
+echo "program will create a custom tcpbw100.html and tcpbw100-java.html files for your site."
echo ""

echo -n "Enter your site name [Internet2] : "
@@ -73,20 +73,39 @@


if test -f tcpbw100.template ; then
- TEMPLATE=tcpbw100.template
+ TEMPLATE_FLASH=../tcpbw100.template
elif test -f ../tcpbw100.template ; then
- TEMPLATE=../tcpbw100.template
+ TEMPLATE_FLASH=../tcpbw100.template
+fi
+
+if test -f tcpbw100-java.template ; then
+ TEMPLATE_JAVA=tcpbw100-java.template
+elif test -f ../tcpbw100.template ; then
+ TEMPLATE_JAVA=../tcpbw100-java.template
+fi
+
+if test -f test-header.html ; then
+ HEADER_PAGE=test-header.html
+elif test -f ../test-header.html ; then
+ HEADER_PAGE=../test-header.html
+fi
+
+if test -f test-description.html ; then
+ DESCRIPTION_PAGE=test-description.html
+elif test -f ../test-description.html ; then
+ DESCRIPTION_PAGE=../test-description.html
fi

# /bin/sed -f /tmp/$$ tcpbw100.template > tcpbw100.html
-/bin/sed -f /tmp/$$ $TEMPLATE > tcpbw100.html
+/bin/sed -f /tmp/$$ $TEMPLATE_FLASH > tcpbw100.html
+/bin/sed -f /tmp/$$ $TEMPLATE_JAVA > tcpbw100-java.html
/bin/rm -f /tmp/$$

-echo "The base web page 'tcpbw100.html' has now been created. You"
-echo "must move this file into the ndt_DATA directory [/usr/local/ndt]"
+echo "The base web pages 'tcpbw100.html' (with java applet) and 'tcpbw100-java.html (with flash client) has now been created. You"
+echo "must move these files into the ndt_DATA directory [/usr/local/ndt]"
echo "created during the 'make' process."

-echo -n "Do you want to install this file now? [yes] : "
+echo -n "Do you want to install these files now? [yes] : "
read answer
if test "$answer" = "n" -o "$answer" = "no"; then
exit
@@ -100,7 +119,9 @@

if test -w $answer; then
/bin/cp -p tcpbw100.html $answer
-
+ /bin/cp -p tcpbw100-java.html $answer
+ /bin/cp -p $HEADER_PAGE $answer
+ /bin/cp -p $DESCRIPTION_PAGE $answer
# create a default directory to store snaplog and tcpdump files in
if test ! -d $answer/serverdata; then
/bin/mkdir $answer/serverdata
@@ -1,14 +1,14 @@
#!/bin/bash

-# This script creates the basic tcpbw100.html page needed by
+# This script creates the basic tcpbw100.html and tcpbw100-java.html pages needed by
# the NDT server.
#
@@ -1,14 +1,14 @@
# the local link connection info.
#
-# Then create the html file using the tcpbw100.template file
-# modified by sed.
+# Then create the html files using the tcpbw100.template (for page with flash client)
+# and tcpbw100-java.template (for page with java applet) files modified by sed.
#
# Richard Carlson
=======================================